@@ -13,8 +13,8 @@
 
 import copy
 import datetime
-import mock
 import random
+from unittest import mock
 import uuid
 
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
@@ -33,10 +33,14 @@ class FakeShareClient(object):
         self.share_access_rules = mock.Mock()
         self.share_types = mock.Mock()
         self.share_type_access = mock.Mock()
+        self.quotas = mock.Mock()
+        self.share_snapshots = mock.Mock()
+        self.share_snapshot_export_locations = mock.Mock()
         self.shares.resource_class = osc_fakes.FakeResource(None, {})
         self.share_export_locations = mock.Mock()
         self.share_export_locations.resource_class = (
             osc_fakes.FakeResource(None, {}))
+        self.messages = mock.Mock()
 
 
 class ManilaParseException(Exception):
@@ -295,11 +299,12 @@ class FakeShareExportLocation(object):
         attrs = attrs or {}
 
         share_export_location_info = {
-            "fake_uuid": "foo_el_uuid",
+            "created_at": 'time-' + uuid.uuid4().hex,
             "fake_path": "/foo/el/path",
             "fake_share_instance_id": 'share-instance-id' + uuid.uuid4().hex,
+            "fake_uuid": "foo_el_uuid",
             "is_admin_only": False,
-            "created_at": 'time-' + uuid.uuid4().hex,
+            "preferred": False,
             "updated_at": 'time-' + uuid.uuid4().hex,
         }
 
@@ -341,3 +346,248 @@ class FakeShareAccessRule(object):
             share_access_rule),
             loaded=True)
         return share_access_rule
+
+
+class FakeQuotaSet(object):
+    """Fake quota set"""
+
+    @staticmethod
+    def create_fake_quotas(attrs=None):
+        """Create a fake quota set
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+
+        quotas_info = {
+            'gigabytes': 1000,
+            'id': 'tenant-id-c96a43119a40ec7d01794cb8',
+            'share_group_snapshots': 50,
+            'share_groups': 50,
+            'share_networks': 10,
+            'shares': 50,
+            'shapshot_gigabytes': 1000,
+            'snapshots': 50
+        }
+
+        quotas_info.update(attrs)
+        quotas = osc_fakes.FakeResource(info=copy.deepcopy(
+                                        quotas_info),
+                                        loaded=True)
+        return quotas
+
+
+class FakeShareSnapshot(object):
+    """Fake a share snapshot"""
+
+    @staticmethod
+    def create_one_snapshot(attrs=None, methods=None):
+        """Create a fake share snapshot
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_snapshot = {
+            'created_at': datetime.datetime.now().isoformat(),
+            'description': 'description-' + uuid.uuid4().hex,
+            'id': 'snapshot-id-' + uuid.uuid4().hex,
+            'name': 'name-' + uuid.uuid4().hex,
+            'project_id': 'project-id-' + uuid.uuid4().hex,
+            'provider_location': None,
+            'share_id': 'share-id-' + uuid.uuid4().hex,
+            'share_proto': 'NFS',
+            'share_size': 1,
+            'size': 1,
+            'status': None,
+            'user_id': 'user-id-' + uuid.uuid4().hex
+        }
+
+        share_snapshot.update(attrs)
+        share_snapshot = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_snapshot),
+            methods=methods,
+            loaded=True)
+        return share_snapshot
+
+    @staticmethod
+    def create_share_snapshots(attrs=None, count=2):
+        """Create multiple fake snapshots.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share types to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_snapshots = []
+        for n in range(0, count):
+            share_snapshots.append(
+                FakeShareSnapshot.create_one_snapshot(attrs))
+
+        return share_snapshots
+
+
+class FakeSnapshotAccessRule(object):
+    """Fake one or more snapshot access rules"""
+
+    @staticmethod
+    def create_one_access_rule(attrs={}):
+        """Create a fake snapshot access rule
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        snapshot_access_rule = {
+            'access_to': 'demo',
+            'access_type': 'user',
+            'id': 'access_rule-id-' + uuid.uuid4().hex,
+            'state': 'queued_to_apply'
+        }
+
+        snapshot_access_rule.update(attrs)
+        snapshot_access_rule = osc_fakes.FakeResource(info=copy.deepcopy(
+            snapshot_access_rule),
+            loaded=True)
+        return snapshot_access_rule
+
+    @staticmethod
+    def create_access_rules(attrs={}, count=2):
+        """Create multiple fake snapshots.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share types to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        access_rules = []
+        for n in range(0, count):
+            access_rules.append(
+                FakeSnapshotAccessRule.create_one_access_rule(attrs))
+
+        return access_rules
+
+
+class FakeSnapshotExportLocation(object):
+    """Fake one or more export locations"""
+
+    @staticmethod
+    def create_one_export_location(attrs=None):
+        """Create a fake snapshot export location
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+
+        snapshot_export_location_info = {
+            "created_at": 'time-' + uuid.uuid4().hex,
+            "id": "id-" + uuid.uuid4().hex,
+            "is_admin_only": False,
+            "links": [],
+            "path": "/path/to/fake/snapshot/snapshot",
+            "share_snapshot_instance_id": 'instance-id' + uuid.uuid4().hex,
+            "updated_at": 'time-' + uuid.uuid4().hex,
+        }
+
+        snapshot_export_location_info.update(attrs)
+        snapshot_export_location = osc_fakes.FakeResource(info=copy.deepcopy(
+            snapshot_export_location_info),
+            loaded=True)
+        return snapshot_export_location
+
+    @staticmethod
+    def create_export_locations(attrs={}, count=2):
+        """Create multiple fake export locations.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share types to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        export_locations = []
+        for n in range(0, count):
+            export_locations.append(
+                FakeSnapshotExportLocation.create_one_export_location(
+                    attrs))
+
+        return export_locations
+
+
+class FakeMessage(object):
+    """Fake message"""
+
+    @staticmethod
+    def create_one_message(attrs=None):
+        """Create a fake message
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+
+        message = {
+            'id': 'message-id-' + uuid.uuid4().hex,
+            'action_id': '001',
+            'detail_id': '002',
+            'user_message': 'user message',
+            'message_level': 'ERROR',
+            'resource_type': 'SHARE',
+            'resource_id': 'resource-id-' + uuid.uuid4().hex,
+            'created_at': datetime.datetime.now().isoformat(),
+            'expires_at': (
+                datetime.datetime.now() + datetime.timedelta(days=30)
+            ).isoformat(),
+            'request_id': 'req-' + uuid.uuid4().hex,
+        }
+
+        message.update(attrs)
+        message = osc_fakes.FakeResource(info=copy.deepcopy(
+            message),
+            loaded=True)
+        return message
+
+    @staticmethod
+    def create_messages(attrs={}, count=2):
+        """Create multiple fake messages.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share types to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        messages = []
+        for n in range(0, count):
+            messages.append(
+                FakeMessage.create_one_message(attrs))
+
+        return messages
