@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
-
 import manilaclient
 from manilaclient import api_versions
 from manilaclient.tests.unit.v2 import fake_clients as fakes
@@ -175,7 +173,13 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
         return (200, {}, body)
 
     def get_shares_1234(self, **kw):
-        share = {'share': {'id': 1234, 'name': 'sharename'}}
+        share = {
+            'share': {
+                'id': 1234,
+                'name': 'sharename',
+                'status': 'available',
+            },
+        }
         return (200, {}, share)
 
     def get_share_servers_1234(self, **kw):
@@ -456,6 +460,33 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
             }
         elif action in ('unmanage', ):
             assert 'force' in body[action]
+        elif action in (
+                'migration_cancel', 'migration_complete',
+                'migration_get_progress'):
+            assert body[action] is None
+            if 'migration_get_progress' == action:
+                _body = {'total_progress': 50,
+                         'task_state': 'fake_task_state',
+                         'destination_share_server_id': 'fake_dest_id'}
+                return 200, {}, _body
+            elif 'migration_complete' == action:
+                _body = {'destination_share_server_id': 'fake_dest_id'}
+                return 200, {}, _body
+        elif action in (
+                'migration_start', 'migration_check'):
+            assert 'host' in body[action]
+            if 'migration-check':
+                _body = {
+                    'compatible': True,
+                    'capacity': True,
+                    'capability': True,
+                    'writable': True,
+                    'nondisruptive': True,
+                    'preserve_snapshots': True,
+                }
+                return 200, {}, _body
+        elif action == 'reset_task_state':
+            assert 'task_state' in body[action]
 
         resp = 202
         result = (resp, {}, _body)
@@ -584,7 +615,7 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
         return (202, {}, {'share_network_subnet': {}})
 
     def post_shares(self, **kwargs):
-        return (202, {}, {'share': {}})
+        return (202, {}, {'share': {'id': '1234', 'status': 'creating'}})
 
     def post_snapshots(self, **kwargs):
         return (202, {}, {'snapshot': {}})
@@ -592,6 +623,12 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
     def delete_shares_1234(self, **kw):
         return (202, {}, None)
 
+    def delete_shares_share_abc(self, **kw):
+        return (202, {}, None)
+
+    def delete_shares_share_xyz(self, **kw):
+        return (202, {}, None)
+
     def delete_snapshots_1234(self, **kwargs):
         return (202, {}, None)
 
