@@ -12,8 +12,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
+from unittest import mock
+
 import ddt
-import mock
 
 from manilaclient import api_versions
 from manilaclient.tests.unit import utils
