@@ -22,6 +22,7 @@ RESOURCES_PATH = '/share-networks'
 RESOURCE_PATH = "/share-networks/%s"
 RESOURCE_NAME = 'share_network'
 RESOURCES_NAME = 'share_networks'
+ACTION_PATH = RESOURCE_PATH + '/action'
 
 
 class ShareNetwork(common_base.Resource):
@@ -71,7 +72,7 @@ class ShareNetworkManager(base.ManagerWithFind):
         return self._create(RESOURCES_PATH, body, RESOURCE_NAME)
 
     @api_versions.wraps("2.26", "2.50")  # noqa
-    def create(self, neutron_net_id=None, neutron_subnet_id=None,
+    def create(self, neutron_net_id=None, neutron_subnet_id=None,   # noqa
                name=None, description=None):
         """Create share network.
 
@@ -96,7 +97,7 @@ class ShareNetworkManager(base.ManagerWithFind):
         return self._create(RESOURCES_PATH, body, RESOURCE_NAME)
 
     @api_versions.wraps("2.51")  # noqa
-    def create(self, neutron_net_id=None, neutron_subnet_id=None,
+    def create(self, neutron_net_id=None, neutron_subnet_id=None,   # noqa
                name=None, description=None, availability_zone=None):
         values = {}
 
@@ -115,24 +116,6 @@ class ShareNetworkManager(base.ManagerWithFind):
 
         return self._create(RESOURCES_PATH, body, RESOURCE_NAME)
 
-    def add_security_service(self, share_network, security_service):
-        """Associate given security service with a share network.
-
-        :param share_network: share network name, id or ShareNetwork instance
-        :param security_service: name, id or SecurityService instance
-        :rtype: :class:`ShareNetwork`
-        """
-        body = {
-            'add_security_service': {
-                'security_service_id': common_base.getid(security_service),
-            },
-        }
-        return self._create(
-            RESOURCE_PATH % common_base.getid(share_network) + '/action',
-            body,
-            RESOURCE_NAME,
-        )
-
     def remove_security_service(self, share_network, security_service):
         """Dissociate security service from a share network.
 
@@ -195,7 +178,7 @@ class ShareNetworkManager(base.ManagerWithFind):
                             RESOURCE_NAME)
 
     @api_versions.wraps("2.26")  # noqa
-    def update(self, share_network, neutron_net_id=None,
+    def update(self, share_network, neutron_net_id=None,   # noqa
                neutron_subnet_id=None, name=None,
                description=None):
         """Updates a share network.
@@ -246,3 +229,96 @@ class ShareNetworkManager(base.ManagerWithFind):
             path = RESOURCES_PATH + query_string
 
         return self._list(path, RESOURCES_NAME)
+
+    def _action(self, action, share_network, info=None):
+        """Perform a share network 'action'.
+
+        :param action: text with action name.
+        :param share_network: either share_network object or text with its ID.
+        :param info: dict with data for specified 'action'.
+        """
+        body = {action: info}
+        self.run_hooks('modify_body_for_action', body)
+        url = ACTION_PATH % common_base.getid(share_network)
+        return self.api.client.post(url, body=body)
+
+    def add_security_service(self, share_network, security_service):
+        """Associate given security service with a share network.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param security_service: name, id or SecurityService instance
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'security_service_id': common_base.getid(security_service),
+        }
+        return self._action('add_security_service', share_network, info)
+
+    @api_versions.wraps("2.63")
+    def add_security_service_check(self, share_network, security_service,
+                                   reset_operation=False):
+        """Associate given security service with a share network.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param security_service: name, id or SecurityService instance
+        :param reset_operation: start over the check operation
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'security_service_id': common_base.getid(security_service),
+            'reset_operation': reset_operation,
+        }
+        return self._action('add_security_service_check', share_network, info)
+
+    @api_versions.wraps("2.63")
+    def update_share_network_security_service(self, share_network,
+                                              current_security_service,
+                                              new_security_service):
+        """Update current security service to new one of a given share network.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param current_security_service: current name, id or
+        SecurityService instance that will be changed
+        :param new_security_service: new name, id or
+        SecurityService instance that will be updated
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'current_service_id': common_base.getid(current_security_service),
+            'new_service_id': common_base.getid(new_security_service)}
+
+        return self._action('update_security_service', share_network, info)
+
+    @api_versions.wraps("2.63")
+    def update_share_network_security_service_check(
+            self, share_network, current_security_service,
+            new_security_service, reset_operation=False):
+        """Validates if the security service update is supported by all hosts.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param current_security_service: current name, id or
+        SecurityService instance that will be changed
+        :param new_security_service: new name, id or
+        :param reset_operation: start over the check operation
+        SecurityService instance that will be updated
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'current_service_id': common_base.getid(current_security_service),
+            'new_service_id': common_base.getid(new_security_service),
+            'reset_operation': reset_operation
+        }
+
+        return self._action('update_security_service_check',
+                            share_network, info)
+
+    @api_versions.wraps("2.63")
+    def reset_state(self, share_network, state):
+        """Reset state of a share network.
+
+        :param share_network: either share_network object or text with its ID
+        or name.
+        :param state: text with new state to set for share network.
+        """
+        return self._action('reset_status', share_network,
+                            {"status": state})
